searchNodes=[{"ref":"Liveness.html","title":"Liveness","type":"exception","doc":"Liveness offers the eventually higher-order function, which can be used to specify liveness properties, or to busy-wait for a particular condition."},{"ref":"Liveness.html#eventually/3","title":"Liveness.eventually/3","type":"function","doc":"Runs f repeatedly until f succeeds or the number of tries is reached. Particular runs are separated in time by an interval of interval milliseconds. The interval period begins when the function begins execution. This means that if execution takes longer than interval milliseconds, the next try will be attempted immediately after f returns. A function is deemed to have failed if it returns false or nil (a falsy value), or if it crashes (exits, raises, or :erlang.errors out). If the function returns successfully, its return value becomes the value of the call to eventually. If the function returns a falsy value (false or nil) upon the last try, then the Liveness exception is raised. If the function raises an exception upon the last try, this exception is re-raised by eventually with the original stacktrace."},{"ref":"readme.html","title":"Liveness","type":"extras","doc":"Liveness A declarative busy wait."},{"ref":"readme.html#use-in-tests","title":"Liveness - Use in tests","type":"extras","doc":"Use this library to assert on liveness properties of a system. A typical use case is waiting for some asynchronous process to finish in the background before the assertion can be checked. An example of this might be writing data to an eventually consistent store and then waiting for a read operation to return the same data. assert eventually(fn -&gt; {:ok, &quot;expected_result&quot;} == SUT.read() end)"},{"ref":"readme.html#use-in-applications","title":"Liveness - Use in applications","type":"extras","doc":"You can also use this library to set up a synchronization point in your code. The wrapped expression will be re-run multiple times, either until the condition succeeds or the maximum number of retries is reached (which causes an exception to be raised). This way you can be certain that the specified condition holds after eventually returns. An example of this might be calling an external resource that we expect to fail intermittently (sigh). credentials = XYZ.fresh_credentials() user_id = eventually(fn -&gt; FlakyUserService.register_user!(credentials) end) proceed_with(user_id)"},{"ref":"readme.html#semantics","title":"Liveness - Semantics","type":"extras","doc":"The call to eventually will succeed if the passed function returns some value other than false within the provided number of retries. Otherwise, it will either raise a Liveness exception or reraise the last exception raised by the function. By default, eventually will attempt to execute the function 250 times, every 20 milliseconds. Both parameters can be altered by passing them to eventually. So, this: eventually(fn -&gt; ... end) Is equivalent to this: eventually(fn -&gt; ... end, 250, 20)"},{"ref":"readme.html#installation","title":"Liveness - Installation","type":"extras","doc":"The library is available on hex.pm. You can use it in your project by adding it to dependencies: defp deps() do [ {:liveness, &quot;~&gt; 1.0.0&quot;} ] end"},{"ref":"readme.html#license","title":"Liveness - License","type":"extras","doc":"This library is licensed under the MIT License."}]